#!/bin/bash +x
# network-setup - simple frontend to varous connection tools
# (C) Klaus Knopper Mar 2004

PATH="/bin:/sbin:/usr/bin:/usr/sbin:/usr/X11R6/bin:/usr/local/bin"
export PATH

XDIALOG_HIGH_DIALOG_COMPAT=1
export XDIALOG_HIGH_DIALOG_COMPAT

CHECK=""
[ "$1" = "check" ] && CHECK="yes"

# Get root
[ "`id -u`" != "0" ] && exec sudo "$0" "$@"

TMP="/tmp/modemlink.$$"

bailout(){
rm -f "$TMP"
exit $1
}

DIALOG="dialog"
[ -n "$DISPLAY" ] && [ -x /usr/bin/Xdialog ] && DIALOG="Xdialog"

trap bailout 1 2 3 15

# LANGUAGE etc.
[ -f /etc/sysconfig/knoppix ] && . /etc/sysconfig/knoppix
[ -z "$LANG" ] && export LANG
[ -z "$LANGUAGE" ] && export LANGUAGE
[ -z "$CHARSET" ] && export CHARSET

gauge(){
rm -f "$TMP.done"
status=0
while [ ! -e "$TMP.done" ]; do echo "$status" ; status="`expr \( 100 - $status \) / 4 + $status`"; sleep 1; done | $DIALOG --gauge "$1" 8 75 0
}

# Stop status bar
killgauge(){
touch "$TMP.done" ; wait ; rm -f "$TMP.done"
}

main(){
gauge "Network Check..." &
# Check network status
STATUS=""
GW="$(route -n | awk '/^0\.0\.0\.0/{print $2}')"
GWDEV="$(route -n | awk '/^0\.0\.0\.0/{print $NF}')"
NMAP="$(nmap -sP --host_timeout 4000 --max_rtt_timeout 4000 "$GW" 2>/dev/null)"
if [ "$?" = 0 ]; then
echo "$NMAP" | grep -q "down" >/dev/null 2>&1 || STATUS="online"
fi
killgauge
if [ -n "$STATUS" ]; then
[ -n "$CHECK" ] && exit 0 # exit if we are already connected
STATUS="Online ($GWDEV)"
else
STATUS="Offline"
fi

# Language-dependent Messages
case "$LANGUAGE" in
de*|at*|ch*)
TITLE1="Netzwerk-Setup"
STATUS="Status: $STATUS"
MESSAGE1="Bitte auswhlen:"
MODEMSETUP="/dev/modem-Schnittstelle (neu) konfigurieren"
NETCARD="Netzwerkkarten (LAN) Zugang"
WIRELESS="Wireless Zugang"
GPRS="Einwahl per Handy/GPRS"
DSL="Einwahl per DSL-Splitter"
ISDN="Einwahl per ISDN"
MODEM="Einwahl per Analogmodem"
;;
*)
TITLE1="Network Setup"
STATUS="Current state: $STATUS"
MESSAGE1="Please select:"
MODEMSETUP="(re)configure /dev/modem device"
NETCARD="network card (LAN) access"
WIRELESS="Wireless access"
GPRS="Dial via cellphone/GPRS"
DSL="Dial via DSL-adapter"
ISDN="Dial via ISDN"
MODEM="Dial via analog modem"
;;
esac

# Shortcut description selected
TYPES=(modemlink "$MODEMSETUP" \
netcardconfig "$NETCARD" \
wlcardconfig "$WIRELESS" \
gprsconnect "$GPRS" \
pppoeconf "$DSL" \
isdntool "$ISDN" \
wvdial "$MODEM")

type wvdial >/dev/null 2>&1 || { unset TYPES[13]; unset TYPES[12]; }
type isdntool >/dev/null 2>&1 || { unset TYPES[11]; unset TYPES[10]; }
type pppoeconf >/dev/null 2>&1 || { unset TYPES[9]; unset TYPES[8]; }
type gprsconnect >/dev/null 2>&1 || { unset TYPES[7]; unset TYPES[6]; }
type wlcardconfig >/dev/null 2>&1 || { unset TYPES[5]; unset TYPES[4]; }

rm -f "$TMP"
$DIALOG --clear --title "$TITLE1" --menu "$STATUS
$MESSAGE1" 19 75 10 "${TYPES[@]}" 2>"$TMP" || bailout 1
read TYPE <"$TMP"
TYPE="${TYPE#\"}"; TYPE="${TYPE%\"}"
rm -f "$TMP"
case "$TYPE" in wvdial) [ -e /etc/wvdial.conf ] || wvdialconf /etc/wvdial.conf;; esac
eval $TYPE
return "$?"
}

while true; do main; done
